@@ -11,18 +11,18 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
+"""Ready2Go Browser Layer
 """
-$Id: __init__.py 97 2007-03-29 22:58:27Z rineichen $
-"""
-
-from zope.viewlet.interfaces import IViewletManager
-import z3c.layer.pagelet
 import z3c.form.interfaces
 import z3c.formui.interfaces
+import z3c.layer.pagelet
+from zope.viewlet.interfaces import IViewletManager
 
 
-class IReady2GoBrowserLayer(z3c.layer.pagelet.IPageletBrowserLayer,
-    z3c.formui.interfaces.IDivFormLayer, z3c.form.interfaces.IFormLayer):
+class IReady2GoBrowserLayer(
+        z3c.layer.pagelet.IPageletBrowserLayer,
+        z3c.formui.interfaces.IDivFormLayer,
+        z3c.form.interfaces.IFormLayer):
     """A ready 2 go layer useful for custom applications."""
 
 
@@ -40,4 +40,3 @@ class IBreadcrumb(IViewletManager):
 
 class ISideBar(IViewletManager):
     """SideBar viewlet manager."""
-
